<?php
/**
 * Plugin Name: Remove Copyright by Corenexis
 * Plugin URI: https://corenexis.com/wordpress
 * Description: Easily modify, remove or replace footer copyright text in WordPress themes. Simple way to eliminate theme credits and customize your site's footer with your own branding using text, selector, or HTML methods.
 * Version: 1.0.2
 * Author: Corenexis
 * Author URI: https://corenexis.com
 * Text Domain: remove-copyright-by-corenexis
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// Add options page under Tools
function rcbc_add_plugin_page() {
    add_management_page(
        'Change Copyright Settings', 
        'Change Copyright', 
        'manage_options', 
        'remove-copyright-by-corenexis', 
        'rcbc_create_admin_page'
    );
}
add_action('admin_menu', 'rcbc_add_plugin_page');

// Add settings link on plugin page
function rcbc_add_settings_link($links) {
    $settings_link = '<a href="tools.php?page=remove-copyright-by-corenexis">Configure Copyright</a>';
    array_unshift($links, $settings_link);
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'rcbc_add_settings_link');

// Add Change Copyright link to plugin meta
function rcbc_plugin_meta($links, $file) {
    if (plugin_basename(__FILE__) == $file) {
        $links[] = '<a href="' . admin_url('tools.php?page=remove-copyright-by-corenexis') . '">Change Copyright</a>';
    }
    return $links;
}
add_filter('plugin_row_meta', 'rcbc_plugin_meta', 10, 2);

// Admin page callback
function rcbc_create_admin_page() {
    $options = get_option('remove_copyright_settings', array());
    ?>
    <div class="wrap">
        <h1>Change Copyright Settings</h1>
        <p>Use this tool to easily modify or replace footer copyright text in your WordPress theme.</p>
        
        <form method="post" action="options.php">
        <?php
            settings_fields('remove_copyright_option_group');
            do_settings_sections('remove-copyright-by-corenexis');
            submit_button('Save Changes', 'primary', 'submit', true);
        ?>
        </form>
        
        <div style="margin-top: 30px; padding: 20px; background: #f9f9f9; border: 1px solid #ddd; border-radius: 4px;">
            <h2 style="margin-top: 0;">About Remove Copyright by Corenexis</h2>
            <p>This plugin allows you to easily change or remove the copyright text and theme credits from your WordPress website footer. Choose from three different methods to target and replace the exact text you want.</p>
            <div style="display: flex; align-items: center; margin-top: 15px;">
                <div style="margin-right: 15px;">
                    <img src="<?php echo plugin_dir_url(__FILE__) . 'logo.webp'; ?>" alt="Corenexis Logo" style="max-width: 177px;">
                </div>
                <div>
                    <p><strong>Plugin developed by Corenexis</strong></p>
                    <p>Explore more plugins and WordPress resources at <a href="https://corenexis.com/wordpress" target="_blank">Corenexis WordPress Resources</a></p>
                </div>
            </div>
        </div>
    </div>
    <?php
}

// Register and add settings
function rcbc_page_init() {
    register_setting(
        'remove_copyright_option_group',
        'remove_copyright_settings',
        'rcbc_sanitize'
    );

    add_settings_section(
        'setting_section_id',
        'Copyright Modification Settings',
        'rcbc_print_section_info',
        'remove-copyright-by-corenexis'
    );

    // Add settings fields
    add_settings_field(
        'method',
        'Replacement Method',
        'rcbc_method_callback',
        'remove-copyright-by-corenexis',
        'setting_section_id'
    );

    add_settings_field(
        'find_text',
        'Text to Find',
        'rcbc_find_text_callback',
        'remove-copyright-by-corenexis',
        'setting_section_id'
    );

    add_settings_field(
        'replace_text',
        'Replace With',
        'rcbc_replace_text_callback',
        'remove-copyright-by-corenexis',
        'setting_section_id'
    );

    add_settings_field(
        'selector',
        'CSS Selector (Class or ID)',
        'rcbc_selector_callback',
        'remove-copyright-by-corenexis',
        'setting_section_id'
    );

    add_settings_field(
        'text_color',
        'Text Color',
        'rcbc_text_color_callback',
        'remove-copyright-by-corenexis',
        'setting_section_id'
    );

    add_settings_field(
        'enabled',
        'Enable Changes',
        'rcbc_enabled_callback',
        'remove-copyright-by-corenexis',
        'setting_section_id'
    );
}
add_action('admin_init', 'rcbc_page_init');

// Sanitize each setting field as needed
function rcbc_sanitize($input) {
    $new_input = array();
    
    if(isset($input['method']))
        $new_input['method'] = sanitize_text_field($input['method']);
    
    if(isset($input['find_text']))
        $new_input['find_text'] = wp_kses_post($input['find_text']);
    
    if(isset($input['replace_text']))
        $new_input['replace_text'] = wp_kses_post($input['replace_text']);
    
    if(isset($input['selector']))
        $new_input['selector'] = sanitize_text_field($input['selector']);
    
    if(isset($input['text_color']))
        $new_input['text_color'] = sanitize_hex_color($input['text_color']);
    
    if(isset($input['enabled']))
        $new_input['enabled'] = absint($input['enabled']);
    
    return $new_input;
}

// Print the Section text
function rcbc_print_section_info() {
    echo '<p>Configure how you want to change or remove copyright text on your website:</p>';
}

// Get the settings option array and print values
function rcbc_method_callback() {
    $options = get_option('remove_copyright_settings', array());
    $method = isset($options['method']) ? esc_attr($options['method']) : 'by_selector';
    ?>
    <select id="method" name="remove_copyright_settings[method]" class="change-method">
        <option value="by_text" <?php selected($method, 'by_text'); ?>>By Text</option>
        <option value="by_selector" <?php selected($method, 'by_selector'); ?>>By Class or ID name (Recommended)</option>
        <option value="by_code" <?php selected($method, 'by_code'); ?>>By Code</option>
    </select>
    <p class="description">Select the method you want to use to modify copyright text. Using Class or ID selectors is recommended for best results.</p>
    <?php
}

function rcbc_find_text_callback() {
    $options = get_option('remove_copyright_settings', array());
    $value = isset($options['find_text']) ? esc_textarea($options['find_text']) : '';
    ?>
    <textarea id="find_text" name="remove_copyright_settings[find_text]" rows="4" cols="50" class="large-text code method-field method-by_text method-by_code"><?php echo $value; ?></textarea>
    <p class="description method-description method-by_text">Enter the exact copyright text you want to replace</p>
    <p class="description method-description method-by_code">Enter the exact HTML code containing the copyright that you want to replace</p>
    <?php
}

function rcbc_replace_text_callback() {
    $options = get_option('remove_copyright_settings', array());
    $value = isset($options['replace_text']) ? esc_textarea($options['replace_text']) : '';
    ?>
    <textarea id="replace_text" name="remove_copyright_settings[replace_text]" rows="4" cols="50" class="large-text code"><?php echo $value; ?></textarea>
    <p class="description">Enter the new text you want to display instead of the original copyright text. You can use HTML tags.</p>
    <?php
}

function rcbc_selector_callback() {
    $options = get_option('remove_copyright_settings', array());
    $value = isset($options['selector']) ? esc_attr($options['selector']) : '';
    ?>
    <input type="text" id="selector" name="remove_copyright_settings[selector]" value="<?php echo $value; ?>" class="regular-text method-field method-by_selector" />
    <p class="description method-description method-by_selector">Enter the CSS selector (class with . or ID with #) of the copyright element. Example: <code>.site-info</code> or <code>#copyright</code></p>
    <?php
}

function rcbc_text_color_callback() {
    $options = get_option('remove_copyright_settings', array());
    $value = isset($options['text_color']) ? esc_attr($options['text_color']) : '#000000';
    ?>
    <input type="text" id="text_color" name="remove_copyright_settings[text_color]" value="<?php echo $value; ?>" class="color-picker" data-default-color="#000000" />
    <p class="description">Choose the color for your new copyright text</p>
    <?php
}

function rcbc_enabled_callback() {
    $options = get_option('remove_copyright_settings', array());
    $value = isset($options['enabled']) ? esc_attr($options['enabled']) : 0;
    ?>
    <input type="checkbox" id="enabled" name="remove_copyright_settings[enabled]" value="1" <?php checked($value, 1); ?> />
    <p class="description">Check to activate copyright modification. Uncheck to temporarily disable without losing your settings.</p>
    <?php
}

// Enqueue admin scripts
function rcbc_enqueue_admin_scripts($hook) {
    if('tools_page_remove-copyright-by-corenexis' != $hook) {
        return;
    }
    
    // Add WordPress color picker
    wp_enqueue_style('wp-color-picker');
    wp_enqueue_script('wp-color-picker');
    
    // Admin styles
    echo '<style>
        .wrap h1 { margin-bottom: 15px; }
        .form-table th { padding: 20px 10px; }
        .method-field, .method-description { display: none; }
    </style>';
    
    // Add inline script for toggling fields
    wp_add_inline_script('wp-color-picker', '
        jQuery(document).ready(function($) {
            // Initialize color picker
            $(".color-picker").wpColorPicker();
            
            // Handle showing/hiding fields based on method
            function toggleFields() {
                var method = $(".change-method").val();
                
                // Hide all method fields and descriptions
                $(".method-field, .method-description").hide();
                
                // Show fields relevant to selected method
                $(".method-" + method).show();
            }
            
            // Run on page load
            toggleFields();
            
            // Run when method changes
            $(".change-method").on("change", toggleFields);
        });
    ');
}
add_action('admin_enqueue_scripts', 'rcbc_enqueue_admin_scripts');

// Add copyright replacer script to frontend
function rcbc_add_footer_script() {
    $options = get_option('remove_copyright_settings', array());
    
    // Check if plugin is enabled
    if (!isset($options['enabled']) || $options['enabled'] != 1) {
        return;
    }
    
    // Get method and other settings
    $method = isset($options['method']) ? $options['method'] : 'by_selector';
    $find_text = isset($options['find_text']) ? $options['find_text'] : '';
    $replace_text = isset($options['replace_text']) ? $options['replace_text'] : '';
    $selector = isset($options['selector']) ? $options['selector'] : '';
    $text_color = isset($options['text_color']) ? $options['text_color'] : '#000000';
    
    // Output the script directly to avoid file dependency
    ?>
    <script type="text/javascript">
    (function($) {
        'use strict';
        
        $(document).ready(function() {
            var method = '<?php echo esc_js($method); ?>';
            var findText = '<?php echo esc_js($find_text); ?>';
            var replaceText = '<?php echo esc_js($replace_text); ?>';
            var selector = '<?php echo esc_js($selector); ?>';
            var textColor = '<?php echo esc_js($text_color); ?>';
            
            // Create styled replacement HTML
            var styledReplace = '<span style="color:' + textColor + ';">' + replaceText + '</span>';
            
            switch(method) {
                case 'by_text':
                    if (!findText) return;
                    
                    // Function to replace text in DOM
                    function replaceTextInNode(node) {
                        if (node.nodeType === 3) { // Text node
                            var text = node.nodeValue;
                            if (text.indexOf(findText) > -1) {
                                var temp = document.createElement('div');
                                temp.innerHTML = text.replace(
                                    findText, 
                                    styledReplace
                                );
                                
                                var fragment = document.createDocumentFragment();
                                while (temp.firstChild) {
                                    fragment.appendChild(temp.firstChild);
                                }
                                
                                node.parentNode.replaceChild(fragment, node);
                                return true;
                            }
                        } else if (node.nodeType === 1 && 
                                   node.nodeName !== 'SCRIPT' && 
                                   node.nodeName !== 'STYLE') {
                            var childNodes = node.childNodes;
                            for (var i = 0; i < childNodes.length; i++) {
                                i += replaceTextInNode(childNodes[i]) ? 1 : 0;
                            }
                        }
                        return false;
                    }
                    
                    // Start replacing text throughout the document
                    replaceTextInNode(document.body);
                    break;
                    
                case 'by_selector':
                    if (!selector) return;
                    
                    $(selector).html(styledReplace);
                    break;
                    
                case 'by_code':
                    if (!findText) return;
                    
                    // Try to find matching elements with jQuery
                    $('body').find('*').each(function() {
                        var $this = $(this);
                        if ($this.html() && $this.html().indexOf(findText) > -1) {
                            // Found element containing the code, now replace it
                            var newContent = $this.html().replace(findText, styledReplace);
                            $this.html(newContent);
                        }
                    });
                    
                    // Also try with plain JavaScript for better HTML matching
                    var allElements = document.getElementsByTagName('*');
                    for (var i = 0, len = allElements.length; i < len; i++) {
                        var element = allElements[i];
                        if (element.innerHTML && element.innerHTML.indexOf(findText) > -1) {
                            element.innerHTML = element.innerHTML.replace(findText, styledReplace);
                        }
                    }
                    break;
            }
        });
    })(jQuery);
    </script>
    <?php
}
add_action('wp_footer', 'rcbc_add_footer_script');

// Check for logo file on activation and create placeholder if needed
function rcbc_plugin_activation() {
    $logo_path = plugin_dir_path(__FILE__) . 'logo.webp';
    
    // If logo file doesn't exist, create a placeholder text file
    if (!file_exists($logo_path)) {
        // Create a placeholder file with instructions
        $placeholder_content = "Please place your logo.webp file in this directory.";
        @file_put_contents($logo_path . '.txt', $placeholder_content);
    }
}
register_activation_hook(__FILE__, 'rcbc_plugin_activation');
